@@ -6,29 +6,29 @@ package SPVM::Double;
 
 SPVM::Double - Double Utility
 
-=head1 CONSTANT FUNCTIONS
+=head1 CLASS METHODS
 
 =head2 MIN_VALUE
 
-B<sub MIN_VALUE : double ()>
+B<sub MIN_VALUE : double ($class : class)>
 
 A constant holding the minimum value a double can have, C<-128>.
 
 =head2 MAX_VALUE
 
-B<sub MAX_VALUE : double ()>
+B<sub MAX_VALUE : double ($class : class)>
 
 A constant holding the maximum value a double can have, C<127>.
 
 =head2 SIZE
 
-B<sub SIZE : int ()>
+B<sub SIZE : int ($class : class)>
 
 The number of bits used to represent a double value in two's complement binary form.
 
 =head2 BYTES
 
-B<sub BYTES : int ()>
+B<sub BYTES : int ($class : class)>
 
 The number of doubles used to represent a double value in two's complement binary form.
 
