@@ -6,29 +6,29 @@ package SPVM::Float;
 
 SPVM::Float - Float Utility
 
-=head1 CONSTANT FUNCTIONS
+=head1 CLASS METHODS
 
 =head2 MIN_VALUE
 
-B<sub MIN_VALUE : float ()>
+B<sub MIN_VALUE : float ($class : class)>
 
 A constant holding the minimum value a float can have, C<-128>.
 
 =head2 MAX_VALUE
 
-B<sub MAX_VALUE : float ()>
+B<sub MAX_VALUE : float ($class : class)>
 
 A constant holding the maximum value a float can have, C<127>.
 
 =head2 SIZE
 
-B<sub SIZE : int ()>
+B<sub SIZE : int ($class : class)>
 
 The number of bits used to represent a float value in two's complement binary form.
 
 =head2 BYTES
 
-B<sub BYTES : int ()>
+B<sub BYTES : int ($class : class)>
 
 The number of floats used to represent a float value in two's complement binary form.
 
