@@ -62,7 +62,7 @@ struct SPVM_api {
   void (*set_double_field)(SPVM_API*, SPVM_API_OBJECT*, int32_t, double);
   void (*set_object_field)(SPVM_API*, SPVM_API_OBJECT*, int32_t, SPVM_API_OBJECT*);
   int32_t (*get_sub_id)(SPVM_API*, const char*);
-  int32_t (*get_method_sub_id)(SPVM_API*, SPVM_API_OBJECT* object, const char*);
+  int32_t (*get_sub_id_interface_method)(SPVM_API*, SPVM_API_OBJECT* object, int32_t);
   int32_t (*get_class_method_sub_id)(SPVM_API*, const char*, const char*);
   void (*call_void_sub)(SPVM_API* api, int32_t sub_id, SPVM_API_VALUE* args);
   int8_t (*call_byte_sub)(SPVM_API* api, int32_t sub_id, SPVM_API_VALUE* args);
@@ -106,5 +106,6 @@ struct SPVM_api {
   void (*weaken_object_field)(SPVM_API* api, SPVM_API_OBJECT* object, int32_t field_id);
   SPVM_API_OBJECT* (*create_exception_stack_trace)(SPVM_API* api, SPVM_API_OBJECT* excetpion, int32_t sub_id, int32_t current_line);
   int32_t (*compile_jit_sub)(SPVM_API* api, int32_t sub_id);
+  int32_t (*check_cast)(SPVM_API* api, int32_t cast_type_id, SPVM_API_OBJECT* object);
 };
 #endif
