@@ -255,6 +255,7 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "LOOKUP_SWITCH",
   "GOTO",
   "CALL_SUB",
+  "CALL_INTERFACE_METHOD",
   "RETURN",
   "CROAK",
   "LOAD_EXCEPTION_VAR",
@@ -321,8 +322,7 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "PUSH_ARG_FLOAT",
   "PUSH_ARG_DOUBLE",
   "PUSH_ARG_OBJECT",
-  "CALL_METHOD",
-  "CALL_CLASS_METHOD",
+  "CHECK_CAST",
 };
 
 SPVM_OPCODE* SPVM_OPCODE_new(SPVM_COMPILER* compiler) {
