@@ -255,6 +255,7 @@ enum {
   SPVM_OPCODE_C_ID_LOOKUP_SWITCH,
   SPVM_OPCODE_C_ID_GOTO,
   SPVM_OPCODE_C_ID_CALL_SUB,
+  SPVM_OPCODE_C_ID_CALL_INTERFACE_METHOD,
   SPVM_OPCODE_C_ID_RETURN,
   SPVM_OPCODE_C_ID_CROAK,
   SPVM_OPCODE_C_ID_LOAD_EXCEPTION_VAR,
@@ -321,8 +322,7 @@ enum {
   SPVM_OPCODE_C_ID_PUSH_ARG_FLOAT,
   SPVM_OPCODE_C_ID_PUSH_ARG_DOUBLE,
   SPVM_OPCODE_C_ID_PUSH_ARG_OBJECT,
-  SPVM_OPCODE_C_ID_CALL_METHOD,
-  SPVM_OPCODE_C_ID_CALL_CLASS_METHOD,
+  SPVM_OPCODE_C_ID_CHECK_CAST,
 };
 
 enum {
