@@ -29,6 +29,7 @@
 #include "spvm_list.h"
 #include "spvm_opcode_array.h"
 #include "spvm_constant.h"
+#include "spvm_hash.h"
 
 SPVM_API_VALUE SPVM_RUNTIME_call_sub(SPVM_API* api, int32_t sub_id, SPVM_API_VALUE* args) {
   (void)api;
@@ -1580,46 +1581,81 @@ SPVM_API_VALUE SPVM_RUNTIME_call_sub_vm(SPVM_API* api, int32_t sub_id, SPVM_API_
         call_sub_args[call_sub_arg_stack_top] = vars[opcode->operand0];
         
         break;
+      case SPVM_OPCODE_C_ID_CHECK_CAST: {
+        SPVM_API_OBJECT* object = *(SPVM_API_OBJECT**)&vars[opcode->operand1];
+        int32_t object_type_id = *(int32_t*)(object + SPVM_RUNTIME_C_OBJECT_TYPE_ID_BYTE_OFFSET);
+        int32_t cast_type_id = opcode->operand2;
+        
+        if (object_type_id == cast_type_id) {
+          *(SPVM_API_OBJECT**)&vars[opcode->operand0] = object;
+        }
+        else {
+          _Bool can_assign = api->check_cast(api, cast_type_id, object);
+          if (can_assign) {
+            *(SPVM_API_OBJECT**)&vars[opcode->operand0] = object;
+          }
+          else {
+            SPVM_API_OBJECT* exception = api->new_string(api, "Can't cast uncompatible type.", 0);
+            api->set_exception(api, exception);
+            croak_flag = 1;
+          }
+        }
+        
+        break;
+      }
       case SPVM_OPCODE_C_ID_CALL_SUB:
+      case SPVM_OPCODE_C_ID_CALL_INTERFACE_METHOD:
       {
-        // Get subroutine ID
-        int32_t call_sub_id = opcode->operand1;
+        int32_t decl_sub_id = opcode->operand1;
+
+        // Declare subroutine
+        SPVM_OP* op_sub_decl = SPVM_LIST_fetch(compiler->op_subs, decl_sub_id);
+        SPVM_SUB* decl_sub = op_sub_decl->uv.sub;
         
-        // Constant pool sub
-        SPVM_OP* op_call_sub = SPVM_LIST_fetch(compiler->op_subs, call_sub_id);
-        SPVM_SUB* call_sub = op_call_sub->uv.sub;
+        // Declare subroutine return type
+        SPVM_TYPE* decl_sub_return_type = decl_sub->op_return_type->uv.type;
         
-        // Subroutine return type
-        SPVM_TYPE* call_sub_return_type = call_sub->op_return_type->uv.type;
+        // Declare subroutine return type id
+        int32_t decl_sub_return_type_id = decl_sub_return_type->id;
         
-        // Subroutine return type id
-        int32_t call_sub_return_type_id = call_sub_return_type->id;
+        // Declare subroutine argument length
+        int32_t decl_sub_args_length = decl_sub->op_args->length;
         
-        // Subroutine argument length
-        int32_t call_sub_args_length = call_sub->op_args->length;
+        // Call subroutine id
+        int32_t call_sub_id;
+        if (opcode->id == SPVM_OPCODE_C_ID_CALL_SUB) {
+           call_sub_id = decl_sub_id;
+        }
+        else if (opcode->id == SPVM_OPCODE_C_ID_CALL_INTERFACE_METHOD) {
+          SPVM_API_OBJECT* object = *(SPVM_API_OBJECT**)&vars[opcode->operand2];
+          call_sub_id = api->get_sub_id_interface_method(api, object, decl_sub_id);
+        }
+        else {
+          assert(0);
+        }
         
-        call_sub_arg_stack_top -= call_sub_args_length;
+        call_sub_arg_stack_top -= decl_sub_args_length;
         
         // Call subroutine
-        if (call_sub_return_type_id == SPVM_TYPE_C_ID_VOID) {
+        if (decl_sub_return_type_id == SPVM_TYPE_C_ID_VOID) {
           api->call_void_sub(api, call_sub_id, call_sub_args);
         }
-        else if (call_sub_return_type_id == SPVM_TYPE_C_ID_BYTE) {
+        else if (decl_sub_return_type_id == SPVM_TYPE_C_ID_BYTE) {
           *(SPVM_API_byte*)&vars[opcode->operand0] = api->call_byte_sub(api, call_sub_id, call_sub_args);
         }
-        else if (call_sub_return_type_id == SPVM_TYPE_C_ID_SHORT) {
+        else if (decl_sub_return_type_id == SPVM_TYPE_C_ID_SHORT) {
           *(SPVM_API_short*)&vars[opcode->operand0] = api->call_short_sub(api, call_sub_id, call_sub_args);
         }
-        else if (call_sub_return_type_id == SPVM_TYPE_C_ID_INT) {
+        else if (decl_sub_return_type_id == SPVM_TYPE_C_ID_INT) {
           *(SPVM_API_int*)&vars[opcode->operand0] = api->call_int_sub(api, call_sub_id, call_sub_args);
         }
-        else if (call_sub_return_type_id == SPVM_TYPE_C_ID_LONG) {
+        else if (decl_sub_return_type_id == SPVM_TYPE_C_ID_LONG) {
           *(SPVM_API_long*)&vars[opcode->operand0] = api->call_long_sub(api, call_sub_id, call_sub_args);
         }
-        else if (call_sub_return_type_id == SPVM_TYPE_C_ID_FLOAT) {
+        else if (decl_sub_return_type_id == SPVM_TYPE_C_ID_FLOAT) {
           *(float*)&vars[opcode->operand0] = api->call_float_sub(api, call_sub_id, call_sub_args);
         }
-        else if (call_sub_return_type_id == SPVM_TYPE_C_ID_DOUBLE) {
+        else if (decl_sub_return_type_id == SPVM_TYPE_C_ID_DOUBLE) {
           *(double*)&vars[opcode->operand0] = api->call_double_sub(api, call_sub_id, call_sub_args);
         }
         else {
@@ -1629,6 +1665,7 @@ SPVM_API_VALUE SPVM_RUNTIME_call_sub_vm(SPVM_API* api, int32_t sub_id, SPVM_API_
         if (api->get_exception(api)) {
           croak_flag = 1;
         }
+        
         break;
       }
       case SPVM_OPCODE_C_ID_IF_CROAK_CATCH: {
