@@ -26,6 +26,10 @@
 #include "spvm_my.h"
 #include "spvm_op.h"
 #include "spvm_list.h"
+#include "spvm_op_checker.h"
+
+
+
 
 
 
@@ -58,7 +62,7 @@ static const void* SPVM_NATIVE_INTERFACE[]  = {
   SPVM_RUNTIME_API_set_double_field,
   SPVM_RUNTIME_API_set_object_field,
   SPVM_RUNTIME_API_get_sub_id,
-  SPVM_RUNTIME_API_get_method_sub_id,
+  SPVM_RUNTIME_API_get_sub_id_interface_method,
   SPVM_RUNTIME_API_get_class_method_sub_id,
   SPVM_RUNTIME_API_call_void_sub,
   SPVM_RUNTIME_API_call_byte_sub,
@@ -101,9 +105,23 @@ static const void* SPVM_NATIVE_INTERFACE[]  = {
   SPVM_RUNTIME_API_concat_string_string,
   SPVM_RUNTIME_API_weaken_object_field,
   SPVM_RUNTIME_API_create_exception_stack_trace,
-  NULL
+  NULL,
+  SPVM_RUNTIME_API_check_cast,
 };
 
+int32_t SPVM_RUNTIME_API_check_cast(SPVM_API* api, int32_t cast_type_id, SPVM_OBJECT* object) {
+  (void)api;
+  
+  SPVM_RUNTIME* runtime = SPVM_RUNTIME_API_get_runtime();
+  SPVM_COMPILER* compiler = runtime->compiler;
+  
+  SPVM_TYPE* cast_type = SPVM_LIST_fetch(compiler->types, cast_type_id);
+ 
+  SPVM_TYPE* object_type = SPVM_LIST_fetch(compiler->types, object->type_id);
+  
+  return SPVM_OP_CHECKER_can_assign(compiler, cast_type, object_type);
+}
+
 SPVM_OBJECT* SPVM_RUNTIME_API_create_exception_stack_trace(SPVM_API* api, SPVM_OBJECT* exception, int32_t sub_id, int32_t current_line) {
 
   SPVM_RUNTIME* runtime = SPVM_RUNTIME_API_get_runtime();
@@ -1163,6 +1181,27 @@ int32_t SPVM_RUNTIME_API_get_sub_id(SPVM_API* api, const char* name) {
   return sub_id;
 }
 
+int32_t SPVM_RUNTIME_API_get_sub_id_interface_method(SPVM_API* api, SPVM_OBJECT* object, int32_t decl_sub_id) {
+  (void)api;
+  
+  SPVM_RUNTIME* runtime = SPVM_RUNTIME_API_get_runtime();
+  SPVM_COMPILER* compiler = runtime->compiler;
+  
+  SPVM_OP* op_sub_decl_sub = SPVM_LIST_fetch(compiler->op_subs, decl_sub_id);
+
+  const char* method_signature = op_sub_decl_sub->uv.sub->method_signature;
+  
+  int32_t type_id = object->type_id;
+  
+  SPVM_TYPE* type = SPVM_LIST_fetch(compiler->types, type_id);
+  
+  SPVM_PACKAGE* package = type->op_package->uv.package;
+  
+  SPVM_SUB* sub_call_sub = SPVM_HASH_search(package->method_signature_symtable, method_signature, strlen(method_signature));
+  
+  return  sub_call_sub->id;
+}
+
 int32_t SPVM_RUNTIME_API_get_method_sub_id(SPVM_API* api, SPVM_OBJECT* object, const char* sub_name) {
   (void)api;
   
