@@ -49,10 +49,10 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
   
   while(1) {
     // Get current character
-    char c = *compiler->bufptr;
+    char ch = *compiler->bufptr;
     
     // line end
-    switch(c) {
+    switch (ch) {
       case '\0':
         compiler->cur_file = NULL;
         free(compiler->cur_src);
@@ -197,6 +197,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
       /* Skip space character */
       case ' ':
       case '\t':
+      case '\r':
         compiler->bufptr++;
         continue;
 
@@ -766,7 +767,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
       }
       default:
         /* Variable */
-        if (c == '$') {
+        if (ch == '$') {
           /* Save current position */
           const char* cur_token_ptr = compiler->bufptr;
           
@@ -801,7 +802,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           return VAR_NAME;
         }
         /* Number literal */
-        else if (isdigit(c)) {
+        else if (isdigit(ch)) {
           const char* cur_token_ptr;
           
           // Before character is minus
@@ -1019,7 +1020,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
           return CONSTANT;
         }
         // Keyword or name
-        else if (isalpha(c) || c == '_') {
+        else if (isalpha(ch) || ch == '_') {
           // Save current position
           const char* cur_token_ptr = compiler->bufptr;
           
@@ -1208,12 +1209,17 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_INT);
                   return INT;
                 }
+                else if (strcmp(keyword, "interface") == 0) {
+                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_INTERFACE, compiler->cur_file, compiler->cur_line);
+                  yylvalp->opval = op_descriptor;
+                  
+                  return DESCRIPTOR;
+                }
                 break;
               case 'j' :
                 if (strcmp(keyword, "jit") == 0) {
-                  SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_DESCRIPTOR);
-                  op->id = SPVM_DESCRIPTOR_C_ID_JIT;
-                  yylvalp->opval = op;
+                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_JIT, compiler->cur_file, compiler->cur_line);
+                  yylvalp->opval = op_descriptor;
                   
                   return DESCRIPTOR;
                 }
@@ -1244,9 +1250,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                 break;
               case 'n' :
                 if (strcmp(keyword, "native") == 0) {
-                  SPVM_OP* op = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_DESCRIPTOR);
-                  op->id = SPVM_DESCRIPTOR_C_ID_NATIVE;
-                  yylvalp->opval = op;
+                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_NATIVE, compiler->cur_file, compiler->cur_line);
+                  yylvalp->opval = op_descriptor;
                   
                   return DESCRIPTOR;
                 }
@@ -1278,9 +1283,21 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                   compiler->before_is_package = 1;
                   
                   yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_PACKAGE);
+                  
                   return PACKAGE;
                 }
-                
+                else if (strcmp(keyword, "private") == 0) {
+                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_PRIVATE, compiler->cur_file, compiler->cur_line);
+                  yylvalp->opval = op_descriptor;
+                  
+                  return DESCRIPTOR;
+                }
+                else if (strcmp(keyword, "public") == 0) {
+                  SPVM_OP* op_descriptor = SPVM_OP_new_op_descriptor(compiler, SPVM_DESCRIPTOR_C_ID_PUBLIC, compiler->cur_file, compiler->cur_line);
+                  yylvalp->opval = op_descriptor;
+                  
+                  return DESCRIPTOR;
+                }
                 break;
               case 'r' :
                 if (strcmp(keyword, "return") == 0) {
@@ -1346,6 +1363,8 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
                 break;
             }
           }
+
+    
           
           if (has_double_underline) {
             fprintf(stderr, "Can't contain __ in package, subroutine or field name at %s line %" PRId32 "\n", compiler->cur_file, compiler->cur_line);
@@ -1383,7 +1402,7 @@ int SPVM_yylex(SPVM_YYSTYPE* yylvalp, SPVM_COMPILER* compiler) {
         compiler->bufptr++;
         yylvalp->opval = SPVM_TOKE_newOP(compiler, SPVM_OP_C_ID_NULL);
         
-        return (int) (uint8_t) c;
+        return (int) (uint8_t) ch;
     }
   }
 }
